@@ -10,14 +10,9 @@ define([
     const { BLOCK_GROUP_TYPE
             , BLOCK_CODELINE_TYPE
             , BLOCK_DIRECTION
-            , IMPORT_BLOCK_TYPE
             , IF_BLOCK_CONDITION_TYPE
-            , FOCUSED_PAGE_TYPE
-            
-            , DEF_BLOCK_ARG4_TYPE
 
             , FOR_BLOCK_ARG3_TYPE
-            , WHILE_BLOCK_TYPE 
 
             , STR_GRP_DEFINE
             , STR_GRP_CONTROL
@@ -59,76 +54,49 @@ define([
             , STR_KEYWORD_NEW_LINE
 
             , VP_ID_PREFIX 
-            , VP_ID_APIBLOCK_LEFT_TAP_APILIST_PAGE
 
             , VP_CLASS_PREFIX 
  
             , VP_BLOCK_BLOCKCODELINETYPE_CODE
             , VP_BLOCK_BLOCKCODELINETYPE_CLASS_DEF
             , VP_BLOCK_BLOCKCODELINETYPE_CONTROL
+            , VP_BLOCK_BLOCKCODELINETYPE_API
  
-            , VP_CLASS_BLOCK_CODETYPE_NAME
-            , VP_CLASS_APIBLOCK_BOARD
-            , VP_CLASS_APIBLOCK_BUTTONS
-            , VP_CLASS_APIBLOCK_OPTION_TAB
-            , VP_CLASS_APIBLOCK_OPTION_INPUT_REQUIRED
-            , VP_CLASS_APIBLOCK_PARAM_PLUS_BTN
             , VP_CLASS_APIBLOCK_BODY 
 
-            , STATE_classInParamList
-            , STATE_className
+            , STATE_metadata
+
             , STATE_parentClassName
             
-            , STATE_defName
             , STATE_defInParamList
             , STATE_defReturnType
 
-            , STATE_ifCodeLine
-            , STATE_isIfElse
-            , STATE_isForElse
+        
             , STATE_ifConditionList
             , STATE_elifConditionList
  
-            , STATE_elifCodeLine
-            , STATE_elifList
- 
-            , STATE_forCodeLine
+    
             , STATE_forParam 
-            , STATE_listforConditionList
-            , STATE_listforReturnVar
-            , STATE_listforPrevExpression
+
  
-            , STATE_whileCodeLine
             , STATE_whileBlockOptionType
             , STATE_whileArgs
             , STATE_whileConditionList
 
-            , STATE_breakCodeLine
-            , STATE_passCodeLine
-            , STATE_continueCodeLine
  
             , STATE_baseImportList
             , STATE_customImportList
  
-            , STATE_exceptList
-            , STATE_exceptCodeLine
             , STATE_exceptConditionList
  
-            , STATE_isFinally
  
             , STATE_returnOutParamList
  
             , STATE_codeLine
  
-            , STATE_propertyCodeLine
- 
-            , STATE_commentLine
- 
             , STATE_lambdaArg1
             , STATE_lambdaArg2List
-            , STATE_lambdaArg2m_List
             , STATE_lambdaArg3
-            , STATE_lambdaArg4List
  
             , COLOR_GRAY_input_your_code
             , COLOR_FOCUSED_PAGE
@@ -299,7 +267,7 @@ define([
                 name = STR_TEXT;
                 break;
             }
-            case BLOCK_CODELINE_TYPE.HOLDER: {
+            case BLOCK_CODELINE_TYPE.SHADOW: {
                 name = '';
                 break;
             }
@@ -326,10 +294,10 @@ define([
         return lastArray;
     }
     
+    /** block데이터를 배열에 담을때 INDENT direction과 direction 타입의 위치 변경
+    *  DOWN 앞으로, INDENT 뒤로
+    */
     var SetChildBlockList_down_first_indent_last = function( stack, blockList ) {
-        /** block데이터를 배열에 담을때 INDENT 타입과 DOWN 타입의 위치 변경
-         *  DOWN 앞으로, INDENT 뒤로
-         */
         blockList = blockList.sort((block1, block2) => {
             if (block1.getDirection() == BLOCK_DIRECTION.INDENT) {
                 return 1;
@@ -365,6 +333,18 @@ define([
         $(trigger).prev(vpCommon.formatString(".{0}", vpConst.MANUAL_CODE_INPUT_AREA_LINE)).val(sbLineText.toString());
     }
 
+    /** api code 반환 */
+    var GenerateApiCode = function(thatBlock) {
+        var metadata = thatBlock.getState(STATE_metadata);
+        if (metadata) {
+            var code = metadata.code;
+            if (code) {
+                return code;
+            }
+        }
+        return '';
+    }
+
     /** class param 생성 */
     var GenerateClassInParamList = function(thatBlock) {
         var parentClassName = thatBlock.getState(STATE_parentClassName);
@@ -375,13 +355,13 @@ define([
     }
  
     /** def param 생성 */
-    var GenerateDefInParamList = function(thatBlock) {
+    var GenerateDefCode = function(thatBlock) {
          /** 함수 파라미터 */
          var defInParamList = thatBlock.getState(STATE_defInParamList);
          var defReturnTypeState = thatBlock.getState(STATE_defReturnType);
          var defInParamStr = `(`;
          defInParamList.forEach(( defInParam, index ) => {
-            const { arg3, arg4, arg5 ,arg6 } = defInParam;
+            const { arg3, arg5 ,arg6 } = defInParam;
                  
             if (arg6 == '*args') {
                 defInParamStr += '*';
@@ -391,16 +371,6 @@ define([
  
             defInParamStr += arg3;
  
-            if (arg4 == DEF_BLOCK_ARG4_TYPE.NONE || arg4 == STR_EMPTY) {
-                defInParamStr += '';
-            } else {
-                   
-                if (arg4 != DEF_BLOCK_ARG4_TYPE.INPUT_STR) {
-                    defInParamStr += ':';
-                    defInParamStr += arg4;
-                } 
-            }
- 
             if (arg5 !== '') {
                 defInParamStr += `=${arg5}`;
             }
@@ -413,24 +383,12 @@ define([
             };
          });
          defInParamStr += `)`;
-
-         if (defReturnTypeState == DEF_BLOCK_ARG4_TYPE.NONE || defReturnTypeState == STR_EMPTY) {
-            defInParamStr += `:`;
-         } else {
-            if (defReturnTypeState != DEF_BLOCK_ARG4_TYPE.INPUT_STR) {
-                defInParamStr += ` `;
-                defInParamStr += `->`;
-                defInParamStr += ` `;
-                defInParamStr += defReturnTypeState;
-                defInParamStr += `:`;
-            } 
-         }
  
          return defInParamStr;
     }
  
     /** return param 생성 */
-    var GenerateReturnOutParamList = function(thatBlock) {
+    var GenerateReturnCode = function(thatBlock) {
         var returnOutParamList = thatBlock.getState(STATE_returnOutParamList);
         var returnOutParamStr = ` `;
         returnOutParamList.forEach(( returnInParam, index ) => {
@@ -449,7 +407,7 @@ define([
     }
  
     /** if param 생성 */
-    var GenerateIfConditionList = function(thatBlock, blockCodeLineType) {
+    var GenerateIfCode = function(thatBlock, blockCodeLineType) {
          var ifConditionList;
          if (blockCodeLineType == BLOCK_CODELINE_TYPE.IF) {
              ifConditionList = thatBlock.getState(STATE_ifConditionList);
@@ -508,62 +466,45 @@ define([
     }
  
       /** while param 생성 */
-    var GenerateWhileConditionList = function(thatBlock) {
+    var GenerateWhileCode = function(thatBlock) {
         var ifConditionList = thatBlock.getState(STATE_whileConditionList);
  
-
         var ifConditionListStr = ``;
         ifConditionList.forEach(( ifCondition, index ) => {
-            // const { conditionType } = ifCondition;
-            // if (conditionType == IF_BLOCK_CONDITION_TYPE.ARG) {
-                const { arg1, arg2, arg3, arg4, arg5, arg6 } = ifCondition;
+    
+            const { arg1, arg2, arg3, arg4, arg5, arg6 } = ifCondition;
 
-               if ( !(arg1 == '' && (arg2 == 'none' || arg2 == '') && arg3 == '')) {
-                   ifConditionListStr += `(`;
-               }
+            if ( !(arg1 == '' && (arg2 == 'none' || arg2 == '') && arg3 == '')) {
+                ifConditionListStr += `(`;
+            }
 
-                ifConditionListStr += arg1;
+            ifConditionListStr += arg1;
  
-                if ( arg2 !== 'none' ) {
-                   ifConditionListStr += arg2;
-                }
-                ifConditionListStr += arg3;
+            if ( arg2 !== 'none' ) {
+                ifConditionListStr += arg2;
+            }
+            ifConditionListStr += arg3;
         
-                if ( arg4 !== 'none' ) {
-                    ifConditionListStr += arg4;
-                    ifConditionListStr += arg5;
-                }
+            if ( arg4 !== 'none' ) {
+                ifConditionListStr += arg4;
+                ifConditionListStr += arg5;
+            }
                 
-                if ( !(arg1 == '' && (arg2 == 'none' || arg2 == '') && arg3 == '')) {
-                   ifConditionListStr += `)`;
-               }
+            if ( !(arg1 == '' && (arg2 == 'none' || arg2 == '') && arg3 == '')) {
+                ifConditionListStr += `)`;
+            }
         
-                if ( ifConditionList.length -1 !== index ) {
-                    ifConditionListStr += '';
-                    ifConditionListStr += arg6;
-                    ifConditionListStr += '';
-                }
-            // } else {
-                // const { codeLine, arg6 } = ifCondition;
-                // if (codeLine == '') {
-                //     return;
-                // }
-                // ifConditionListStr += `(`;
-                // ifConditionListStr += codeLine;
-                // ifConditionListStr += `)`;
-
-                // if ( ifConditionList.length -1 !== index ) {
-                //     ifConditionListStr += '';
-                //     ifConditionListStr += arg6;
-                //     ifConditionListStr += '';
-                // }
-            // }
-
+            if ( ifConditionList.length -1 !== index ) {
+                ifConditionListStr += '';
+                ifConditionListStr += arg6;
+                ifConditionListStr += '';
+            }
         });
 
        return ifConditionListStr;
     }
-     var GenerateExceptConditionList = function(thatBlock) {
+
+    var GenerateExceptCode = function(thatBlock) {
          var exceptConditionList = thatBlock.getState(STATE_exceptConditionList);
  
          var exceptConditionListStr = ``;
@@ -597,7 +538,7 @@ define([
      }
  
      /** for param 생성 */
-     var GenerateForParam = function(thatBlock) {
+     var GenerateForCode = function(thatBlock) {
          var forParam = thatBlock.getState(STATE_forParam);
          const { arg1, arg2, arg3, arg4, arg5, arg6, arg7 } = forParam;
  
@@ -682,147 +623,13 @@ define([
                 }
             }
 
-         }
+        }
 
-         return forParamStr;
-     }
- 
-     /** Listfor param 생성 */
-     var GenerateListforConditionList = function(thatBlock) {
-         var listforStr = '';
-         var listforReturnVar = thatBlock.getState(STATE_listforReturnVar);
-         var listforPrevExpression = thatBlock.getState(STATE_listforPrevExpression);
- 
-         if (listforReturnVar != '') {
-             listforStr += listforReturnVar;
-             listforStr += ' ';
-             listforStr += '=';
-             listforStr += ' ';
-         }
- 
-         listforStr += '[';
-         listforStr += listforPrevExpression;
- 
- 
-         var listforConditionList = thatBlock.getState(STATE_listforConditionList);
-         listforConditionList.forEach(listforCondition => {
-             const { arg1, arg2, arg3, arg4, arg5, arg6, arg7
-                     , arg10, arg11, arg12, arg13, arg14, arg15  } = listforCondition;
- 
-             listforStr += ' ';
-             listforStr += 'for';
-             listforStr += ' ';
-             if (arg1 !== '') {
-                 listforStr += arg1;
-                 listforStr += ' ';
-             }
-     
-             if (arg3 == 'enumerate' && arg1 !== '' && arg4 !== '') { 
-                 listforStr += ',';
-             }
-     
-             if (arg3 == 'enumerate' && arg4 !== '') {
-                 listforStr += arg4;
-                 listforStr += ' ';
-             }
-     
-             listforStr += 'in';
-             listforStr += ' ';
-     
-             if (arg3 == 'zip') {
-                 listforStr += arg3;
-                 listforStr += '(';
-                 listforStr += arg2;
-     
-                 if (arg7 !== '') {
-                     listforStr += ',';
-                     listforStr += ' ';
-                     listforStr += arg7;
-                 }
-     
-                 listforStr += ')';
-     
-             } else if (arg3 == 'enumerate') {
-                 listforStr += arg3;
-                 listforStr += '(';
-                 listforStr += arg2;
-                 listforStr += ')';
-     
-             } else if (arg3 == 'range') {
-                 listforStr += arg3;
-                 listforStr += '(';
-     
-                 if (arg5 !== '') {
-                     listforStr += arg5;
-                 }
-     
-                 if (arg5 !== '' && arg2 !== '') { 
-                     listforStr += ',';
-                 }
-     
-                 if (arg2 !== '') {
-                     listforStr += ' ';
-                     listforStr += arg2;
-                 }
-     
-                 if ((arg5 !== '' || arg2 !== '') && arg6 !== '') { 
-                     listforStr += ',';
-                 }
-     
-                 if (arg6 !== '') {
-                     listforStr += ' ';
-                     listforStr += arg6;
-                 }
-       
-                 listforStr += ')';
-     
-             } 
+        return forParamStr;
+    }
 
-            else {
-                if (arg3 != FOR_BLOCK_ARG3_TYPE.INPUT_STR) {
-                    listforStr += arg3;
-                } 
-    
-                if (arg2 != '') {
-                    if (arg3 == '' || arg3 == FOR_BLOCK_ARG3_TYPE.INPUT_STR) {
-                        listforStr += arg2;
-                    } else {
-                        listforStr += '(';
-                        listforStr += arg2;
-                        listforStr += ')';
-                    }
-                }
-            }
  
-            if (arg10 == 'if') {
-                listforStr += ' ';
-                listforStr += 'if';
-                listforStr += ' ';
-                listforStr += `(`;
-         
-                listforStr += arg11;
-                listforStr += arg12;
-                listforStr += arg13;
-         
-                if ( arg14 !== 'none' ) {
-                    listforStr += arg14;
-                    listforStr += arg15;
-                }
-                 
-                listforStr += ' ';
-                listforStr += `)`;
-                listforStr += '';
-     
-            } else if (arg10 == 'inputStr') {
- 
-            }
-        });
- 
-        listforStr += ']';
-        return listforStr;
-     }
- 
-    var GenerateLambdaParamList = function(thatBlock) {
+    var GenerateLambdaCode = function(thatBlock) {
         var lambdaParamStr = STR_EMPTY;
         var lambdaArg1State = thatBlock.getState(STATE_lambdaArg1);
         var lambdaArg2ListState = thatBlock.getState(STATE_lambdaArg2List);
@@ -853,7 +660,7 @@ define([
         return lambdaParamStr;
      }
 
-     var GenerateImportList = function(thisBlock, indentString) {
+     var GenerateImportCode = function(thisBlock, indentString) {
         var codeLine = STR_EMPTY;
         var blockName = 'import';
         var baseImportList = thisBlock.getState(STATE_baseImportList).filter(baseImport => {
@@ -916,24 +723,6 @@ define([
         return codeLine;
      };
 
-     var GenerateWhileBlockCode = function(thisBlock) {
-        var whileBlockCode = STR_EMPTY;
-        var whileArgsState = thisBlock.getState(STATE_whileArgs)
-        var whileBlockOptionType = thisBlock.getState(STATE_whileBlockOptionType);
-        const { arg1, arg2, arg3, arg4, arg5 } = whileArgsState;
-
-        if (whileBlockOptionType == WHILE_BLOCK_TYPE.CONDITION) {
-            whileBlockCode += arg4;
-            whileBlockCode += arg2;
-            whileBlockCode += arg3;
-        } else if (whileBlockOptionType == WHILE_BLOCK_TYPE.TRUE_FALSE) {
-            whileBlockCode += arg1;
-        } else {
-            whileBlockCode += arg1;
-        }
-        return whileBlockCode;
-     }
-
      var ShowImportListAtBlock = function(thisBlock) {
         var codeLine = STR_EMPTY;
         var baseImportList = thisBlock.getState(STATE_baseImportList).filter(baseImport => {
@@ -974,41 +763,6 @@ define([
     
 
  
-    /** 특정 input태그 값 입력 안 될시 빨간색 border 
-     */
-    var RenderInputRequiredColor = function(thatBlock) {
-        if ($(thatBlock).val() == STR_EMPTY) {
-            $(thatBlock).addClass(VP_CLASS_APIBLOCK_OPTION_INPUT_REQUIRED)
-        } else {
-            $(thatBlock).removeClass(VP_CLASS_APIBLOCK_OPTION_INPUT_REQUIRED); 
-        }
-    }
- 
-    var RenderSelectRequiredColor = function(target, selectedValue) {
-        if (selectedValue == STR_EMPTY) {
-            $(target).addClass(VP_CLASS_APIBLOCK_OPTION_INPUT_REQUIRED)
-        } else {
-            $(target).removeClass(VP_CLASS_APIBLOCK_OPTION_INPUT_REQUIRED); 
-        }
-    }
- 
- 
-    /**
-     * @param {string} inputValue 
-     */
-    var RenderCodeBlockInputRequired = function(thisBlock, inputValue, state) {
-        /** 어떤 데이터도 입력되지 않을 때 */
-        if (inputValue == STR_EMPTY) {
-            thisBlock.writeCode(STR_INPUT_YOUR_CODE);
-            $(`.vp-block-header-${thisBlock.getUUID()}`).css(STR_COLOR, COLOR_GRAY_input_your_code);
-            return;
-        }
- 
-        /** 데이터가 입력되었을 때 */
-        thisBlock.writeCode(state);
-        $(`.vp-block-header-${thisBlock.getUUID()}`).css(STR_COLOR, COLOR_BLACK);
-    }
- 
      var RenderHTMLDomColor = function(block, htmlDom) {
          var blockType = block.getBlockType();
  
@@ -1030,20 +784,21 @@ define([
              || blockType == BLOCK_CODELINE_TYPE.IMPORT
              || blockType == BLOCK_CODELINE_TYPE.LAMBDA
              || blockType == BLOCK_CODELINE_TYPE.PROPERTY ) {
-             //  COLOR_CONTROL;
+        
              $(htmlDom).addClass(VP_BLOCK_BLOCKCODELINETYPE_CONTROL);
- 
-         } else if (blockType == BLOCK_CODELINE_TYPE.BLANK){
-             $(htmlDom).css(STR_BACKGROUND_COLOR, STR_TRANSPARENT);
-    
-         }  else if (blockType == BLOCK_CODELINE_TYPE.TEXT) {
+        } else if (blockType == BLOCK_CODELINE_TYPE.API) {
+            /** API 블럭 */
+            $(htmlDom).addClass(VP_BLOCK_BLOCKCODELINETYPE_API);
+        } else if (blockType == BLOCK_CODELINE_TYPE.TEXT) {
             $(htmlDom).css(STR_BACKGROUND_COLOR, STR_TRANSPARENT);
-         } else if (blockType == BLOCK_CODELINE_TYPE.HOLDER ) {
-
-         } else {
+        } else if (blockType == BLOCK_CODELINE_TYPE.NODE) {
+        
+        } else {
              $(htmlDom).addClass(VP_BLOCK_BLOCKCODELINETYPE_CODE);
-         }
-         return htmlDom;
+        }
+        return htmlDom;
+
+        
     }
  
 
@@ -1073,9 +828,9 @@ define([
             || blockType == BLOCK_CODELINE_TYPE.PASS
             || blockType == BLOCK_CODELINE_TYPE.CONTINUE 
             || blockType == BLOCK_CODELINE_TYPE.BREAK
+
             || blockType == BLOCK_CODELINE_TYPE.PROPERTY
             || blockType == BLOCK_CODELINE_TYPE.PRINT
-            
             || blockType == BLOCK_CODELINE_TYPE.BLANK
             || blockType == BLOCK_CODELINE_TYPE.COMMENT  ) {
             return true;
@@ -1242,25 +997,20 @@ define([
         , IsControlBlockType
 
         , LoadVariableList
-
-        , RenderInputRequiredColor
-        , RenderSelectRequiredColor
-     
-        , RenderCodeBlockInputRequired
         
         , RenderHTMLDomColor
  
+        , GenerateApiCode
+
         , GenerateClassInParamList
-        , GenerateDefInParamList
-        , GenerateReturnOutParamList
-        , GenerateIfConditionList
-        , GenerateExceptConditionList
-        , GenerateForParam
-        , GenerateListforConditionList
-        , GenerateLambdaParamList
-        , GenerateImportList
-        , GenerateWhileBlockCode
-        , GenerateWhileConditionList
+        , GenerateDefCode
+        , GenerateReturnCode
+        , GenerateIfCode
+        , GenerateExceptCode
+        , GenerateForCode
+        , GenerateLambdaCode
+        , GenerateImportCode
+        , GenerateWhileCode
 
         , ShowImportListAtBlock
         , ShowCodeBlockCode
