@@ -422,6 +422,12 @@ define([
      * @param {ENUM} focusedPageType 
      */
     BlockContainer.prototype.setFocusedPageType = function(focusedPageType) {
+        // 추가: FOCUSED_PAGE_TYPE = NULL일 경우 주피터 단축키 활성화 / 아닐 경우 비활성화
+        if (focusedPageType == FOCUSED_PAGE_TYPE.NULL) {
+            Jupyter.notebook.keyboard_manager.enable();
+        } else {
+            Jupyter.notebook.keyboard_manager.disable();
+        }
         this.focusedPageType = focusedPageType;
     }
     BlockContainer.prototype.getFocusedPageType = function() {
@@ -550,6 +556,8 @@ define([
         var apiBlockJsonDataList = [];
         blockList.forEach( (block, index) => {
             if (block.getBlockType() == BLOCK_CODELINE_TYPE.API) {
+                // FIXME: Text 블럭 Metadata load/save 검증 필요
+                //|| block.getBlockType() == BLOCK_CODELINE_TYPE.TEXT) {
                 block.setMetadata();
             }
             // console.log('block',block);
@@ -678,11 +686,12 @@ define([
 
 
                 /** 블럭의 WIDTH값을 계산 */
-                if (blockType == BLOCK_CODELINE_TYPE.TEXT) {
-                    numWidth = NUM_TEXT_BLOCK_WIDTH;
-                } else {
+                // DEPRECATED : TEXT Block도 일반 블럭과 동일하게 너비 계산
+                // if (blockType == BLOCK_CODELINE_TYPE.TEXT) {
+                //     numWidth = NUM_TEXT_BLOCK_WIDTH;
+                // } else {
                     numWidth = this.getBlockMaxWidth() - indentPxNum;
-                }
+                // }
                 var blockMainDom = block.getBlockMainDom();
                 $(blockMainDom).css(STR_MARGIN_LEFT, indentPxNum);
                 $(blockMainDom).css(STR_WIDTH, numWidth);
@@ -748,6 +757,7 @@ define([
         if (rootBlock == null) {
             return;
         }
+        var scrollTop = $(VP_CLASS_PREFIX + VP_CLASS_APIBLOCK_BOARD).scrollTop();
 
         var blockList = rootBlock.getThisToLastBlockList();
         var prevBlockList = this.getPrevBlockList();
@@ -790,7 +800,9 @@ define([
         } else {
             var containerDom = this.reNewContainerDom();
             for await (var block of blockList) {
-                new Promise( (resolve) => resolve( $(containerDom).append(block.getBlockMainDom())));
+                new Promise( (resolve) => resolve( 
+                    $(containerDom).append(block.getBlockMainDom())
+                ));
                 block.bindEventAll();
             }
         }
@@ -809,6 +821,8 @@ define([
             }
         });
         this.setPrevBlockList(blockList);
+
+        $(VP_CLASS_PREFIX + VP_CLASS_APIBLOCK_BOARD).scrollTop(scrollTop);
     }
 
     /** vpnote를 open할 때 실행되는 메소드
@@ -847,12 +861,14 @@ define([
 
                     /** text 블럭 preview에 Markdown 형식의 preview Render */
                     markdownPakage.bindOptionEvent();
-                    markdownPakage.previewRender(block.getImportPakage().uuid, text);
-        
+                    
                     /** option popup에 있는 textarea에 text 블럭 데이터 넣기 */
                     const textarea = block.getBlockOptionPageDom().find(`#vp_markdownEditor`).get(0);
                     $(textarea).val(text);
 
+                    // markdownPakage.previewRender(block.getImportPakage().uuid, text);
+                    markdownPakage.previewRender(text);
+
                     this.resetOptionPage();
                 });
             } 
@@ -937,24 +953,28 @@ define([
         $(containerDom).css(STR_LEFT, NUM_DEFAULT_POS_X + STR_PX);
 
         /** +Node, +Text 버튼 생성 */
-        var sbNodeOrTextPlusButton = new sb.StringBuilder();
-        sbNodeOrTextPlusButton.appendFormatLine("<div id='{0}' class='{1}'>",'vp_apiblock_board_node_plus_button_container',
-                                                                            'vp-apiblock-style-flex-row');
-        sbNodeOrTextPlusButton.appendFormatLine("<div id='{0}' class='{1}'>",'vp_apiblock_board_node_plus_button',
-                                                                            'vp-apiblock-option-plus-button');
-        sbNodeOrTextPlusButton.appendFormatLine("{0}", '+ Node');
-        sbNodeOrTextPlusButton.appendLine("</div>");
+        /** Deprecated: 2021-02-08
+         * block을 보유한 boardContainer가 아닌 상위그룹에 고정시킨 플로팅버튼 형태로 수정
+         * index.html에서 정적으로 관리(계속 생성할 필요 없음)
+         */
+        // var sbNodeOrTextPlusButton = new sb.StringBuilder();
+        // sbNodeOrTextPlusButton.appendFormatLine("<div id='{0}' class='{1}'>",'vp_apiblock_board_node_plus_button_container',
+        //                                                                     'vp-apiblock-style-flex-row');
+        // sbNodeOrTextPlusButton.appendFormatLine("<div id='{0}' class='{1}'>",'vp_apiblock_board_node_plus_button',
+        //                                                                     'vp-apiblock-option-plus-button');
+        // sbNodeOrTextPlusButton.appendFormatLine("{0}", '+ Node');
+        // sbNodeOrTextPlusButton.appendLine("</div>");
 
-        sbNodeOrTextPlusButton.appendFormatLine("<div id='{0}' class='{1}' style='{2}'>",'vp_apiblock_board_text_plus_button',
-                                                                                         'vp-apiblock-option-plus-button',
-                                                                                         'margin-left: 10px');
-        sbNodeOrTextPlusButton.appendFormatLine("{0}", '+ Text');
-        sbNodeOrTextPlusButton.appendLine("</div>");
+        // sbNodeOrTextPlusButton.appendFormatLine("<div id='{0}' class='{1}' style='{2}'>",'vp_apiblock_board_text_plus_button',
+        //                                                                                  'vp-apiblock-option-plus-button',
+        //                                                                                  'margin-left: 10px');
+        // sbNodeOrTextPlusButton.appendFormatLine("{0}", '+ Text');
+        // sbNodeOrTextPlusButton.appendLine("</div>");
 
-        sbNodeOrTextPlusButton.appendLine("</div>");
-        var nodePlusButtonContainer = sbNodeOrTextPlusButton.toString();
+        // sbNodeOrTextPlusButton.appendLine("</div>");
+        // var nodePlusButtonContainer = sbNodeOrTextPlusButton.toString();
 
-        $(containerDom).append(nodePlusButtonContainer);
+        // $(containerDom).append(nodePlusButtonContainer);
 
         $(VP_CLASS_PREFIX + VP_CLASS_APIBLOCK_BOARD).append(containerDom);
         this.setBlockContainerDom(containerDom);
@@ -1016,29 +1036,54 @@ define([
     BlockContainer.prototype.dragBlock = function(isBlock, thisBlock, shadowBlock, selectedBlock, selectedBlockDirection, currCursorX, currCursorY) {
         var blockContainerThis = this;
 
+        // if (isBlock == true) {
+        //     /** 각 node 블럭 영역의 가장 아래의 블럭들을 가져옴 */
+        //     var nodeBlockList = blockContainerThis.getNodeBlockList();
+        //     var lastBlockList_blockArea = []
+        //     nodeBlockList.forEach(nodeBlock => {
+        //         if (thisBlock.getUUID() == nodeBlock.getUUID()) {
+        //             return;
+        //         }
+        //         var lastBlock = nodeBlock.getLastBlock_from_thisBlockArea();
+        //         $( lastBlock.getBlockMainDom() ).css(STR_DISPLAY, STR_BLOCK);
+        //         lastBlockList_blockArea.push(lastBlock);
+        //     });
+        // }
         if (isBlock == true) {
-            /** 각 node 블럭 영역의 가장 아래의 블럭들을 가져옴 */
-            var nodeBlockList = blockContainerThis.getNodeBlockList();
+            /** 각 node, text 블럭 영역의 가장 아래의 블럭들을 가져옴 */
+            var nodeTextBlockList = blockContainerThis.getNodeBlockAndTextBlockList_asc();
             var lastBlockList_blockArea = []
-            nodeBlockList.forEach(nodeBlock => {
-                if (thisBlock.getUUID() == nodeBlock.getUUID()) {
+            nodeTextBlockList.forEach(nodeTextBlock => {
+                if (thisBlock.getUUID() == nodeTextBlock.getUUID()) {
                     return;
                 }
-                var lastBlock = nodeBlock.getLastBlock_from_thisBlockArea();
+                var lastBlock = nodeTextBlock.getLastBlock_from_thisBlockArea();
                 $( lastBlock.getBlockMainDom() ).css(STR_DISPLAY, STR_BLOCK);
                 lastBlockList_blockArea.push(lastBlock);
             });
         }
+        
 
         /** 블록 전체를 돌면서 drag하는 Block과 Board위에 생성된 블록들과 충돌 작용  */
         var boardBlockList = blockContainerThis.getBlockList();
         boardBlockList.forEach( async (block) => {
             var blockType = block.getBlockType();
-            if (blockType == BLOCK_CODELINE_TYPE.TEXT) {
-                return;
-            }
+            // if (blockType == BLOCK_CODELINE_TYPE.TEXT) {
+            //     return;
+            // }
+            
 
             if (isBlock == true) {
+                /**
+                 * 움직이는 블럭이 노드/텍스트 블럭이 아닐 경우
+                 * 텍스트 블럭과 충돌 금지
+                 */
+                if ((   thisBlock.getBlockType() != BLOCK_CODELINE_TYPE.NODE &&
+                        thisBlock.getBlockType() != BLOCK_CODELINE_TYPE.TEXT    ) 
+                        && (blockType == BLOCK_CODELINE_TYPE.TEXT)) {
+                    return;
+                }
+                
                 /** 자기 자신인 블럭과는 충돌 금지 
                  *  혹은 자신의 하위 블럭과도 충돌 금지
                  */
@@ -1047,7 +1092,8 @@ define([
                     return;
                 }
 
-                if (thisBlock.getBlockType() == BLOCK_CODELINE_TYPE.NODE) {
+                if (thisBlock.getBlockType() == BLOCK_CODELINE_TYPE.NODE
+                    || thisBlock.getBlockType() == BLOCK_CODELINE_TYPE.TEXT) {
                     var isLastBlock = lastBlockList_blockArea.some(lastBlock => {
                         if (lastBlock.getUUID() == block.getUUID()) {
                             return true;
@@ -1519,7 +1565,10 @@ define([
         setClosureBlock(createdBlock_api);
         loadOption_block(funcID, optionPageLoadCallback_block);
 
-        this.resetBlockListAndRenderThisBlock(createdBlock_api);
+        // 생성된 블럭을 선택하지 않은 상태로 유지
+        // this.resetBlockListAndRenderThisBlock(createdBlock_api);
+        this.resetBlockList();
+        this.setSelectBlock(null);
     }
 
     /** 블럭을 이동할 때,
@@ -1784,12 +1833,12 @@ define([
         /** text 블럭일 경우 width 계산 */
         if (blockType == BLOCK_CODELINE_TYPE.TEXT) {
             $(blockMainDom).css(STR_BACKGROUND_COLOR, STR_TRANSPARENT);
-            $(blockMainDom).css(STR_WIDTH, NUM_TEXT_BLOCK_WIDTH);
-         /** text 블럭이 아닐 경우 width 계산 */
-        } else {
-            var blockMaxWidth = this.getBlockMaxWidth() - (thisBlock.getDepth() * NUM_INDENT_DEPTH_PX);
-            $(blockMainDom).css(STR_WIDTH, blockMaxWidth);
+            // DEPRECATED : TEXT Block도 일반 블럭과 동일하게 너비 계산
+            // $(blockMainDom).css(STR_WIDTH, NUM_TEXT_BLOCK_WIDTH);
         }
+        /** block width 계산 */
+        var blockMaxWidth = this.getBlockMaxWidth() - (thisBlock.getDepth() * NUM_INDENT_DEPTH_PX);
+        $(blockMainDom).css(STR_WIDTH, blockMaxWidth);
 
         blockMainDom = RenderHTMLDomColor(thisBlock, blockMainDom);
 
@@ -1880,29 +1929,39 @@ define([
 
     /** 코드 생성 */
     BlockContainer.prototype.makeCode = function(thisBlock) {
-        var codeLine = '';
+        var codeLine = STR_EMPTY;
         var rootDepth = thisBlock.getDepth();
         var blockList_thisBlockArea = thisBlock.getBlockList_thisBlockArea_noShadowBlock();
-        blockList_thisBlockArea.some( ( block,index ) => {
+
+        var codeList = [];
+        blockList_thisBlockArea.some( (block,index) => {
+            /** 각 Block의 blockCodeLine에 맞는 코드 생성 */
             var indentString = block.getIndentString(rootDepth);
-            if ( block.getBlockType() == BLOCK_CODELINE_TYPE.API ) {
+            var blockType = block.getBlockType();
+
+            if ( blockType == BLOCK_CODELINE_TYPE.API ) {
                 var apiCodeLine = block.setCodeLineAndGet(indentString, true);
                 if (apiCodeLine.indexOf('BREAK_RUN') != -1) {
-                    codeLine = 'BREAK_RUN';
-                    return true;
+                    // codeLineStr += 'BREAK_RUN';
+                    // return true;
                 } else {
-                    codeLine += apiCodeLine;
+                    codeList.push(apiCodeLine);
                 }
             } else {
-                codeLine += block.setCodeLineAndGet(indentString, false);
+                codeList.push(block.setCodeLineAndGet(indentString, false));
             }
-            codeLine += STR_KEYWORD_NEW_LINE;
         });
+
+        // run all cell
+        codeLine = codeList.join('\n');
+
         vpCommon.setIsAPIListRunCode(true);
         return codeLine;
     }
 
-    /** Run All 버튼 실행시 board에 있는 전체 코드 생성 */
+    /** Run All 버튼 실행시 board에 있는 전체 코드 생성 
+     * FIXME: 노드별로 셀 추가하도록 수정해야 함
+    */
     BlockContainer.prototype.makeAllCode = function() {
         var rootBlock = this.getRootBlock();
         if (!rootBlock) {
@@ -1913,6 +1972,11 @@ define([
         var codeLineStr = STR_EMPTY;
         var blockList = rootBlock.getRootToChildBlockList();
         var rootDepth = rootBlock.getDepth();
+
+        var groupIdx = -1; 
+        var codeList = [
+            /** { type: 'code/markdown', data: '' } */
+        ];
         blockList.some( (block,index) => {
 
             if (block.getBlockType() == BLOCK_CODELINE_TYPE.SHADOW) {
@@ -1921,11 +1985,13 @@ define([
             /** 각 Block의 blockCodeLine에 맞는 코드 생성 */
             var indentString = block.getIndentString(rootDepth);
             var codeLine = STR_EMPTY;
-            if ( block.getBlockType() == BLOCK_CODELINE_TYPE.API ) {
+            var blockType = block.getBlockType();
+
+            if ( blockType == BLOCK_CODELINE_TYPE.API ) {
                 var apiCodeLine = block.setCodeLineAndGet(indentString, true);
                 if (apiCodeLine.indexOf('BREAK_RUN') != -1) {
-                    codeLineStr += 'BREAK_RUN';
-                    return true;
+                    // codeLineStr += 'BREAK_RUN';
+                    // return true;
                 } else {
                     codeLine += apiCodeLine;
                 }
@@ -1933,11 +1999,32 @@ define([
                 codeLine += block.setCodeLineAndGet(indentString, false);
             }
 
-            /**  코드 라인 한 칸 띄우기 */    
-            codeLine += STR_KEYWORD_NEW_LINE;
-            codeLineStr += codeLine;
+            if (blockType == BLOCK_CODELINE_TYPE.NODE) {
+                codeList.push( { type: 'code', data: [ codeLine ] } );
+                groupIdx = codeList.length - 1;
+            } else if (blockType == BLOCK_CODELINE_TYPE.TEXT) {
+                codeList.push( { type: 'markdown', data: [ codeLine ] } );
+                groupIdx = codeList.length - 1;
+            } else {
+                if (codeLine != STR_EMPTY) {
+                    codeList[groupIdx].data.push(codeLine);
+                }
+            }
         });
 
+        // run all cell
+        var cmdList = codeList.map(function(obj) { 
+            var command = obj.data.join('\n');
+            if (command != STR_EMPTY) {
+                if (codeLineStr != STR_EMPTY) {
+                    codeLineStr += '\n';
+                }
+                codeLineStr += command;
+            }
+            return { command: command, type: obj.type, exec: true }
+        });
+        vpCommon.cellExecute(cmdList);
+
         this.setAPIBlockCode(codeLineStr);
         return codeLineStr;
     }
@@ -1988,17 +2075,19 @@ define([
         var buttonsPageRectWidth = NUM_BUTTONS_PAGE_WIDTH; 
         var boardPageRect =  $(vpCommon.wrapSelector(VP_CLASS_PREFIX + VP_CLASS_APIBLOCK_BOARD_CONTAINER))[0].getBoundingClientRect(); 
         var boardPageRectWidth = boardPageRect.width;
-        var optionPageRectWidth = mainPageRectWidthNum - boardPageRectWidth - buttonsPageRectWidth - 103;
+        var optionPageRectWidth = mainPageRectWidthNum - boardPageRectWidth - buttonsPageRectWidth - 43;
 
         if (optionPageRectWidth < NUM_OPTION_PAGE_WIDTH) {
-            boardPageRectWidth = mainPageRectWidthNum - NUM_OPTION_PAGE_WIDTH - 103 - buttonsPageRectWidth;
+            boardPageRectWidth = mainPageRectWidthNum - NUM_OPTION_PAGE_WIDTH - 43 - buttonsPageRectWidth;
+            // optionPageRectWidth = NUM_OPTION_PAGE_WIDTH;
         } 
+        
+        var optionPageRectWidth_maxWidth = mainPageRectWidthNum - buttonsPageRectWidth - NUM_API_BOARD_CENTER_PAGE_MIN_WIDTH - 43;
 
-        var optionPageRectWidth_maxWidth = mainPageRectWidthNum - buttonsPageRectWidth - NUM_API_BOARD_CENTER_PAGE_MIN_WIDTH - 103;
         $(vpCommon.wrapSelector(VP_CLASS_PREFIX + VP_CLASS_APIBLOCK_OPTION_TAB)).css(STR_MAX_WIDTH, optionPageRectWidth_maxWidth);
         $(vpCommon.wrapSelector(VP_CLASS_PREFIX + VP_CLASS_APIBLOCK_BOARD_CONTAINER)).css(STR_WIDTH, boardPageRectWidth );
         $(vpCommon.wrapSelector(VP_CLASS_PREFIX + VP_CLASS_APIBLOCK_OPTION_TAB)).css(STR_WIDTH, optionPageRectWidth );
-        $(VP_ID_PREFIX + VP_ID_WRAPPER).css(STR_MIN_WIDTH, 760);
+        // $(VP_ID_PREFIX + VP_ID_WRAPPER).css(STR_MIN_WIDTH, 760);
 
         this.setBlockMaxWidth_blockList(boardPageRectWidth - 70);
 
