@@ -215,8 +215,8 @@ define([
     const NUM_APIBLOCK_LEFT_PAGE_WIDTH = 140;
     const NUM_OPTION_PAGE_WIDTH = 225;
 
-    const NUM_BUTTONS_PAGE_WIDTH = 140;
-    const NUM_API_BOARD_CENTER_PAGE_WIDTH = 430;
+    const NUM_BUTTONS_PAGE_WIDTH = 200;
+    const NUM_API_BOARD_CENTER_PAGE_WIDTH = 300;
     const NUM_API_BOARD_CENTER_PAGE_MIN_WIDTH = 290;
     const NUM_TEXT_BLOCK_WIDTH = 900;
     /** ---------------------------------------- const String ------------------------------------------ */
@@ -554,6 +554,9 @@ define([
     /** ---------------------------------------- const State Name String ------------------------------------------ */
     const STATE_state = 'state';
 
+    /** Api */
+    const STATE_metadata = 'metadata';
+
     /** Class */
     const STATE_classInParamList = 'classInParamList';
     const STATE_className = 'className';
@@ -1093,6 +1096,8 @@ define([
         
         , STATE_state
 
+        , STATE_metadata
+
         , STATE_classInParamList
         , STATE_className
         , STATE_parentClassName
