@@ -184,6 +184,9 @@ define([
          *  board에 container dom을 렌더링
          */
         blockContainer.reNewContainerDom();
+
+        /** Block Max Width 설정 */
+        blockContainer.setBlockMaxWidth(boardPageRectWidth - 70);
         
         /** delete 키 or 엔터 키를 누를 때 keyup 이벤트 발동
          */
@@ -251,6 +254,9 @@ define([
             $('.vp-block-group-box-' + category).toggle();
         });
 
+        /** 2021-01-28 수정: 주피터쪽을 선택한다고 VisualPython의 포커스를 변경하지 않도록 수정
+         *  2021-02-10 수정: 주피터쪽 선택 여부는 체크, 대신 VisualPython의 작업환경을 초기화하지 않도록 수정
+         */
         /** visual python 화면 이외에 화면(jupyter header 영역 , jupyter cell 영역)을 클릭했을 때, 
          *  page 포커스 해제 
          *  option (N/A) 처리
@@ -260,8 +266,8 @@ define([
                                  ${VP_CLASS_PREFIX}${STR_CELL}, 
                                  ${VP_CLASS_PREFIX}${STR_CODEMIRROR_LINES},
                                  div#notebook`)).click(function(event) {
-            blockContainer.resetBlockList();
-            blockContainer.resetOptionPage();
+            // blockContainer.resetBlockList();
+            // blockContainer.resetOptionPage();
             blockContainer.setFocusedPageType(FOCUSED_PAGE_TYPE.NULL);
         });
         
@@ -289,7 +295,8 @@ define([
 
         /** Board Main Title에서 엔터키 눌렀을 때 */
         $(vpCommon.wrapSelector(VP_ID_PREFIX + "vp_apiblock_board_main_title")).keyup(function(event) {
-            if (event.keyCode == NUM_ENTER_KEY_EVENT_NUMBER) {
+            var keyCode = event.keyCode ? event.keyCode : event.which;
+            if (keyCode == NUM_ENTER_KEY_EVENT_NUMBER) {
                 blockContainer.setFocusedPageType(FOCUSED_PAGE_TYPE.NULL);
                 $(this).find('input').blur();
             }
@@ -336,12 +343,16 @@ define([
                 // console.log('selectedBlock',selectedBlock);
 
                 /** ctrl + c */
-                if (ctrlDown && (e.keyCode == cKey)) {
+                if (ctrlDown 
+                    && e.ctrlKey && (e.keyCode == cKey)
+                    && !e.shiftKey && !e.altKey ) {
                     blockContainer.setCtrlSaveData();
                 }
               
                 /** ctrl + v */
-                if (ctrlDown && (e.keyCode == vKey) ) {
+                if (ctrlDown 
+                    && e.ctrlKey && (e.keyCode == vKey) 
+                    && !e.shiftKey && !e.altKey ) {
                     blockContainer.copyCtrlSaveData();
                 }
             });
