@@ -976,7 +976,6 @@ define([
      * @param {boolean} exec 실행여부
      */
     MatplotPackage.prototype.generateCode = function(addCell, exec) {
-        if (!this.optionValidation()) return;
 
         try {
             var sbCode = new sb.StringBuilder();
@@ -1128,7 +1127,7 @@ define([
                 input: [
                     {
                         name: 'i0',
-                        label: 'axes variable',
+                        label: 'Axes Variable',
                         type: 'int',
                         required: false
                     },
@@ -1171,7 +1170,7 @@ define([
                 input: [
                     {
                         name: 'i0',
-                        label: 'axes variable',
+                        label: 'Axes Variable',
                         type: 'int',
                         required: false
                     },
@@ -1214,7 +1213,7 @@ define([
                 input: [
                     {
                         name: 'i0',
-                        label: 'axes variable',
+                        label: 'Axes Variable',
                         type: 'int',
                         required: false
                     },
@@ -1234,7 +1233,7 @@ define([
                         name: 'bins',
                         type: 'int',
                         required: true,
-                        label: 'bins' // TODO: 라벨명
+                        label: 'Bins' // TODO: 라벨명
                     },
                     {
                         name: 'label',
@@ -1258,7 +1257,7 @@ define([
                 input: [
                     {
                         name: 'i0',
-                        label: 'axes variable',
+                        label: 'Axes Variable',
                         type: 'int',
                         required: false
                     },
@@ -1286,7 +1285,7 @@ define([
                 input: [
                     {
                         name: 'i0',
-                        label: 'axes variable',
+                        label: 'Axes Variable',
                         type: 'int',
                         required: false
                     },
@@ -1326,7 +1325,7 @@ define([
                 input: [
                     {
                         name: 'i0',
-                        label: 'axes variable',
+                        label: 'Axes Variable',
                         type: 'int',
                         required: false
                     },
@@ -1349,7 +1348,7 @@ define([
                 input: [
                     {
                         name: 'i0',
-                        label: 'axes variable',
+                        label: 'Axes Variable',
                         type: 'int',
                         required: false
                     },
@@ -1386,7 +1385,7 @@ define([
                 input: [
                     {
                         name: 'i0',
-                        label: 'axes variable',
+                        label: 'Axes Variable',
                         type: 'int',
                         required: false
                     },
@@ -1423,7 +1422,7 @@ define([
                 input: [
                     {
                         name: 'i0',
-                        label: 'axes variable',
+                        label: 'Axes Variable',
                         type: 'int',
                         required: false
                     },
@@ -1464,7 +1463,7 @@ define([
                 input: [
                     {
                         name: 'i0',
-                        label: 'axes variable',
+                        label: 'Axes Variable',
                         type: 'int',
                         required: false
                     },
@@ -1499,7 +1498,7 @@ define([
                 input: [
                     {
                         name: 'i0',
-                        label: 'axes variable',
+                        label: 'Axes Variable',
                         type: 'int',
                         required: false
                     },
