@@ -129,12 +129,8 @@ define([
      * @param {boolean} exec 실행여부
      */
     PandasPackage.prototype.generateCode = function(addCell, exec) {
-        if (!this.optionValidation()) return;
         
         var sbCode = new sb.StringBuilder();
-        
-        // 생성된 것 표시
-        sbCode.appendLine(`# Auto-Generated by VisualPython`);
 
         // 코드 생성
         var res = $(this.wrapSelector('#cal_result')).val();
