@@ -39,15 +39,16 @@ define([
      * 정의된 설정값을 토대로 입출력 및 옵션 항목 그려주기
      * @param {*} funcSetting 
      */
-    var vp_showInterface = function(divTag, funcSetting) {
-        var divContainer = $(divTag);
+    var vp_showInterface = function(pageThis) {
+        var divTag = pageThis.wrapSelector('');
+        var funcSetting = pageThis.package;
 
         // cell metadata test : metadata 값 받아와서 뿌려주기
-        _VP_CODEMD = Jupyter.notebook.get_selected_cell().metadata.vp;
-        // metadata 값이 없거나, 다른 기능의 메뉴일 경우 초기화
-        if (_VP_CODEMD == undefined || _VP_CODEMD.id != funcSetting.id) {
-            _VP_CODEMD = {};
-        }
+        // _VP_CODEMD = Jupyter.notebook.get_selected_cell().metadata.vp;
+        // // metadata 값이 없거나, 다른 기능의 메뉴일 경우 초기화
+        // if (_VP_CODEMD == undefined || _VP_CODEMD.id != funcSetting.id) {
+        //     _VP_CODEMD = {};
+        // }
 
         // 입력값을 위한 태그 생성
         var tblInput = $(divTag+' #vp_inputOutputBox table');
@@ -55,9 +56,9 @@ define([
             // tblInput.append(vp_createTag(o));
             // cell metadata test
             var obj = JSON.parse(JSON.stringify(o)); // 깊은 복사
-            if ('input' in _VP_CODEMD)
-                obj.value = _VP_CODEMD.input[i].value;
-            tblInput.append(vp_createTag(obj, false, true, (obj.required == false? false: true)));
+            // if ('input' in _VP_CODEMD)
+            //     obj.value = _VP_CODEMD.input[i].value;
+            tblInput.append(vp_createTag(pageThis, obj, false, true, (obj.required == false? false: true)));
         });
 
         // 옵션값을 위한 태그 생성
@@ -66,9 +67,9 @@ define([
             // tblOption.append(vp_createTag(o, true));
             // cell metadata test
             var obj = JSON.parse(JSON.stringify(o)); // 깊은 복사
-            if ('variable' in _VP_CODEMD)
-                obj.value = _VP_CODEMD.variable[i].value;
-            tblOption.append(vp_createTag(obj, true, true, (obj.required == true? true: false)));
+            // if ('variable' in _VP_CODEMD)
+            //     obj.value = _VP_CODEMD.variable[i].value;
+            tblOption.append(vp_createTag(pageThis, obj, true, true, (obj.required == true? true: false)));
         });
 
         // 출력값을 위한 태그 생성
@@ -77,20 +78,21 @@ define([
             // tblOutput.append(vp_createTag(o));
             // cell metadata test
             var obj = JSON.parse(JSON.stringify(o)); // 깊은 복사
-            if ('output' in _VP_CODEMD)
-                obj.value = _VP_CODEMD.output[i].value;
-            tblOutput.append(vp_createTag(obj, false, true, (obj.required == true? true: false)));
+            // if ('output' in _VP_CODEMD)
+            //     obj.value = _VP_CODEMD.output[i].value;
+            tblOutput.append(vp_createTag(pageThis, obj, false, true, (obj.required == true? true: false)));
         });
     }
 
     /**
      * 입출력/옵션의 type에 따라 특정 태그 구현하기
+     * @param {object} pageThis
      * @param {*} obj 
      * @param {boolean} showKey 
      * @param {boolean} getValue 
      * @returns {HTMLTableRowElement} tblRow (TR태그)
      */
-    var vp_createTag = function(obj, showKey=false, getValue=false, required=false) {
+    var vp_createTag = function(pageThis, obj, showKey=false, getValue=false, required=false) {
         // TR 태그 & TD 라벨 태그 생성
         var tblRow = document.createElement('tr');
         // tblRow.innerHTML = ('<td><label for='+obj.name+'>'+ obj.label + (showKey?' ('+obj.name+')':'') +'</label> &nbsp;</td>')
@@ -155,13 +157,14 @@ define([
                 tblInput.appendChild(optSlct);
                 break;
             case 'var_select':
-                // 데이터 프레임 select 태그 구성
-                var tag = document.createElement('select');
+                // 데이터 프레임 suggest input 태그 구성
+                var tag = document.createElement('input');
                 $(tag).attr({
+                    'type': 'text',
                     'id': obj.name,
-                    'class': 'vp-select var-select'
+                    'class': 'vp-input'
                 });
-                vp_generateVarSelect(tag, obj.var_type, obj.value);
+                vp_generateVarSuggestInput(pageThis, obj);
                 tblInput.appendChild(tag);
                 break;
             case 'var_multi':
@@ -182,23 +185,6 @@ define([
                 // break;
             // default : input_single
             default:
-                // var input = document.createElement('input');
-                // $(input).attr({
-                //     'type':'text',
-                //     'class':'input-single',
-                //     'id':obj.name,
-                //     'placeholder':(obj.placeholder==undefined?'':obj.placeholder),
-                //     'value':(obj.default==undefined?'':obj.default),
-                //     'title':(obj.help==undefined?'':obj.help)
-                // });
-                // // cell metadata test
-                // if (getValue && obj.value != undefined) {
-                //     // metadata 에 저장된 값으로 표시
-                //     input.attr({
-                //         'value': obj.value
-                //     });
-                // }
-                // tblInput.appendChild(input);
                 // FIXME: use makedom
                 var input = vpMakeDom.renderInput({
                     'type':'text',
@@ -223,6 +209,48 @@ define([
         return tblRow;
     }
 
+    /**
+     * 알맞은 type 변수 목록을 suggestInput 태그로 반환
+     * @param {object} obj
+     */
+    var vp_generateVarSuggestInput = function(pageThis, obj) {
+        var types = obj.var_type;
+        var defaultValue = obj.value;
+
+        // Index 는 여러 유형의 Index 타입이 있어 하위 타입들도 포함 필요
+        var INDEX_TYPES = ['RangeIndex', 'CategoricalIndex', 'MultiIndex', 'IntervalIndex', 'DatetimeIndex', 'TimedeltaIndex', 'PeriodIndex', 'Int64Index', 'UInt64Index', 'Float64Index'];
+        // GroupBy 는 여러 유형의 GroupyBy 타입이 있어 하위 타입들도 포함시키기
+        var GROUPBY_TYPES = ['DataFrameGroupBy', 'SeriesGroupBy']
+        if (types.indexOf('Index') >= 0) {
+            types = types.concat(INDEX_TYPES);
+        }
+        if (types.indexOf('GroupBy') >= 0) {
+            types = types.concat(GROUPBY_TYPES);
+        }
+
+        vp_searchVarList(types, function (result) {
+            var varList = JSON.parse(result);
+            varList = varList.map(function(v) {
+                return { label: v.varName + ' (' + v.varType + ')', value: v.varName, dtype: v.varType };
+            });
+            // 1. Target Variable
+            var suggestInput = new vpSuggestInputText.vpSuggestInputText();
+            suggestInput.setComponentID(obj.name);
+            suggestInput.addClass('vp-input');
+            suggestInput.setSuggestList(function() { return varList; });
+            suggestInput.setNormalFilter(false);
+            suggestInput.setValue($(pageThis.wrapSelector('#' + obj.name)).val());
+            suggestInput.setSelectEvent(function(selectedValue) {
+                // trigger change
+                $(pageThis.wrapSelector('#' + obj.name)).val(selectedValue);
+                $(pageThis.wrapSelector('#' + obj.name)).trigger('select_suggestvalue');
+            });
+            $(pageThis.wrapSelector('#' + obj.name)).replaceWith(function() {
+                return suggestInput.toTagString();
+            });
+        });
+    }
+
     /**
      * 알맞은 type 목록을 select 태그로 반환
      * @param {object} tag 
@@ -285,10 +313,10 @@ define([
         cmdSB.appendLine('import json');
         cmdSB.append(`print(json.dumps([{'varName': v, 'varType': type(eval(v)).__name__}`);
         cmdSB.append(`for v in dir() if (not v.startswith('_')) `);
+        cmdSB.appendFormat('& (v not in {0})', JSON.stringify(_VP_NOT_USING_VAR));
         if (types != undefined && types.length > 0) {
             cmdSB.appendFormat(`& (type(eval(v)).__name__ in {0})`, JSON.stringify(types));
         } else {
-            cmdSB.appendFormat('& (v not in {0})', JSON.stringify(_VP_NOT_USING_VAR));
             cmdSB.appendFormat(`& (type(eval(v)).__name__ not in {0}) `, JSON.stringify(_VP_NOT_USING_TYPE));
         }
         cmdSB.append(']))');
@@ -450,7 +478,7 @@ define([
                 if (val == undefined || val == ''){
                     if (v.required == undefined || v.required == true) {
                         // throw new Error(v.label+'에 값을 입력해주세요.');
-                        throw new Error("'" + v.label + "' is required.");
+                        // throw new Error("'" + v.label + "' is required.");
                     }
                     // 값이 없을 경우 빈 값으로 파라미터 대체
                     code = code.split(id).join('');
@@ -475,7 +503,7 @@ define([
                 if (val == undefined || val == ''){
                     if (v.required == true) {
                         // throw new Error(v.label+'에 값을 입력해주세요.');
-                        throw new Error("'" + v.label + "' is required.");
+                        // throw new Error("'" + v.label + "' is required.");
                     }
                 }
                 else {
@@ -499,7 +527,7 @@ define([
                 if (val == undefined || val == ''){
                     if (v.required == true) {
                         // throw new Error(v.label+'에 값을 입력해주세요.');
-                        throw new Error("'" + v.label + "' is required.");
+                        // throw new Error("'" + v.label + "' is required.");
                     } else {
                         // 출력 변수 없을 경우 공백으로 만들기
                         code = code.split(id).join('');
@@ -534,7 +562,8 @@ define([
             }
 
         } catch (e) {
-            vpCommon.renderAlertModal(e.message);
+            // vpCommon.renderAlertModal(e.message);
+            console.log('vp error: ' + e.message);
             return null;
         }
         return code;
@@ -552,15 +581,17 @@ define([
      */
     var vp_bindColumnSource = function(pageThis, target, columnInputIdList) {
         var varName = $(target).val();
-        var varType = $(target).find(':selected').data('type');
+        // var varType = $(target).attr('data-type');
 
-        if (varType != 'DataFrame') {
+        // if (varType != 'DataFrame')
+        if (varName === '') {
             // reset with no source
             columnInputIdList && columnInputIdList.forEach(columnInputId => {
                 var suggestInputX = new vpSuggestInputText.vpSuggestInputText();
                 suggestInputX.setComponentID(columnInputId);
                 suggestInputX.addClass('vp-input');
                 suggestInputX.setNormalFilter(false);
+                suggestInputX.setValue($(pageThis.wrapSelector('#' + columnInputId)).val());
                 $(pageThis.wrapSelector('#' + columnInputId)).replaceWith(function() {
                     return suggestInputX.toTagString();
                 });
@@ -574,23 +605,29 @@ define([
                         , varName, varName, varName);
         // get result and show on detail box
         pageThis.kernelExecute(code.toString(), function(result) {
-            var varResult = JSON.parse(result);
-
-            if (varResult.length > 0) {
-                // columns using suggestInput
-                columnInputIdList && columnInputIdList.forEach(columnInputId => {
-                    var suggestInputX = new vpSuggestInputText.vpSuggestInputText();
-                    suggestInputX.setComponentID(columnInputId);
-                    suggestInputX.addClass('vp-input');
-                    suggestInputX.setPlaceholder("column name");
-                    suggestInputX.setSuggestList(function() { return varResult; }); //FIXME:
-                    suggestInputX.setNormalFilter(false);
-                    $(pageThis.wrapSelector('#' + columnInputId)).replaceWith(function() {
-                        return suggestInputX.toTagString();
+            try {
+                var varResult = JSON.parse(result);
+    
+                if (varResult.length > 0) {
+                    // columns using suggestInput
+                    columnInputIdList && columnInputIdList.forEach(columnInputId => {
+                        var suggestInputX = new vpSuggestInputText.vpSuggestInputText();
+                        suggestInputX.setComponentID(columnInputId);
+                        suggestInputX.addClass('vp-input');
+                        suggestInputX.setPlaceholder("column name");
+                        suggestInputX.setSuggestList(function() { return varResult; }); //FIXME:
+                        suggestInputX.setNormalFilter(false);
+                        suggestInputX.setValue($(pageThis.wrapSelector('#' + columnInputId)).val());
+                        $(pageThis.wrapSelector('#' + columnInputId)).replaceWith(function() {
+                            return suggestInputX.toTagString();
+                        });
                     });
-                });
+                }
+            } catch (e) {
+                console.log('not supported data type. ' + e);
             }
         });
+
     }
 
     return {
