@@ -111,7 +111,7 @@ define([
             var axis = $(that.wrapSelector('#axis')).val();
             // axis = 열(1) 이면 컬럼목록 표시
             if (axis == '1') {
-                pdGen.vp_bindColumnSource(that, this, ['i1']);
+                pdGen.vp_bindColumnSource(that, $(this), ['i1']);
             } else {
                 $(that.wrapSelector('#i1')).replaceWith(function() {
                     return $(`<input id="i1" type="text" class="vp-input" />`);
@@ -134,7 +134,7 @@ define([
         });
 
         // HTML 구성
-        pdGen.vp_showInterface(this.wrapSelector(''), this.package);
+        pdGen.vp_showInterface(this);
 
         // move 'axis' option to required box
         $(this.wrapSelector('#axis')).closest('tr').insertBefore(
@@ -150,7 +150,6 @@ define([
      * @param {boolean} exec 실행여부
      */
     PandasPackage.prototype.generateCode = function(addCell, exec) {
-        if (!this.optionValidation()) return;
         
         var sbCode = new sb.StringBuilder();
         
