@@ -177,13 +177,21 @@ define([
                 if (idx > -1) {
                     that.package.variable[idx].required = true;
                     // 라벨 필수 입력 표시
-                    $(that.wrapSelector('#x')).closest('tr').find('label').text(`* ${that.package.variable[idx].label}(${that.package.variable[idx].name})`);
+                    // $(that.wrapSelector('#x')).closest('tr').find('label').text(`* ${that.package.variable[idx].label} (${that.package.variable[idx].name})`);
+                    var tag = $(that.wrapSelector('#x')).closest('tr').find('label');
+                    if (!$(tag).hasClass(vpConst.COLOR_FONT_ORANGE)) {
+                        $(that.wrapSelector('#x')).closest('tr').find('label').addClass(vpConst.COLOR_FONT_ORANGE);
+                    }
                 }
                 var idy = that.package.variable.findIndex(function(item) {return item.name === 'y'});
                 if (idy > -1) {
                     that.package.variable[idy].required = true;
                     // 라벨 필수 입력 표시
-                    $(that.wrapSelector('#y')).closest('tr').find('label').text(`* ${that.package.variable[idy].label}(${that.package.variable[idy].name})`);
+                    // $(that.wrapSelector('#y')).closest('tr').find('label').text(`* ${that.package.variable[idy].label} (${that.package.variable[idy].name})`);
+                    var tag = $(that.wrapSelector('#y')).closest('tr').find('label');
+                    if (!$(tag).hasClass(vpConst.COLOR_FONT_ORANGE)) {
+                        $(that.wrapSelector('#y')).closest('tr').find('label').addClass(vpConst.COLOR_FONT_ORANGE);
+                    }
                 }
             } else {
                 that.package = libPandas._PANDAS_FUNCTION[funcOptProp.libID];
@@ -191,11 +199,13 @@ define([
                 // 라벨 재정비
                 var idx = that.package.variable.findIndex(function(item) {return item.name === 'x'});
                 if (idx > -1) {
-                    $(that.wrapSelector('#x')).closest('tr').find('label').text(`${that.package.variable[idx].label}(${that.package.variable[idx].name})`);
+                    // $(that.wrapSelector('#x')).closest('tr').find('label').text(`${that.package.variable[idx].label} (${that.package.variable[idx].name})`);
+                    $(that.wrapSelector('#x')).closest('tr').find('label').removeClass(vpConst.COLOR_FONT_ORANGE);
                 }
                 var idy = that.package.variable.findIndex(function(item) {return item.name === 'y'});
                 if (idy > -1) {
-                    $(that.wrapSelector('#y')).closest('tr').find('label').text(`${that.package.variable[idy].label}(${that.package.variable[idy].name})`);
+                    // $(that.wrapSelector('#y')).closest('tr').find('label').text(`${that.package.variable[idy].label} (${that.package.variable[idy].name})`);
+                    $(that.wrapSelector('#y')).closest('tr').find('label').removeClass(vpConst.COLOR_FONT_ORANGE);
                 }
             }
         });
@@ -283,7 +293,7 @@ define([
         });
 
         // on dataframe change
-        $(document).on('change', this.wrapSelector('#i0'), function() {
+        $(document).on('select_suggestvalue change', this.wrapSelector('#i0'), function() {
             // dataframe columns search
             pdGen.vp_bindColumnSource(that, this, ['x', 'y']);
         });
@@ -294,7 +304,7 @@ define([
      */
     PandasPackage.prototype.bindOptions = function() {
         // HTML 구성
-        pdGen.vp_showInterface(this.wrapSelector(''), this.package);
+        pdGen.vp_showInterface(this);
 
         $(this.wrapSelector('#x')).closest('tr').insertBefore('#vp_inputOutputBox tbody tr:last');
         $(this.wrapSelector('#y')).closest('tr').insertBefore('#vp_inputOutputBox tbody tr:last');
@@ -305,16 +315,9 @@ define([
      * @param {boolean} exec 실행여부
      */
     PandasPackage.prototype.generateCode = function(addCell, exec) {
-        if (!this.optionValidation()) return;
         
         try {
             var sbCode = new sb.StringBuilder();
-            
-            // add prefix code
-            var prefixCode = $(this.wrapSelector('#vp_prefixBox textarea')).val();
-            if (prefixCode.length > 0) {
-                sbCode.appendLine(prefixCode);
-            }
 
             // 사용자 옵션 설정값 가져오기
             var userOption = new sb.StringBuilder();
@@ -345,12 +348,6 @@ define([
 
             // cell metadata 작성하기
             // pdGen.vp_setCellMetadata(_VP_CODEMD);
-            // add postfix code
-            var postfix = $(this.wrapSelector('#vp_postfixBox textarea')).val();
-            if (postfix.length > 0) {
-                sbCode.appendLine('');
-                sbCode.append(postfix);
-            }
 
             if (addCell) this.cellExecute(sbCode.toString(), exec);
         } catch (exmsg) {
