@@ -106,7 +106,7 @@
             height: 'calc(100% - 180px)',
             width: '50%',
             right: '10px',
-            top: '150px'
+            top: '110px'
         };
         $.extend(true, defaultConfig.vpPosition, vpPosition);
     }
@@ -224,31 +224,36 @@
      * @param {*} st 
      */
     function setNotebookWidth(cfg, st) {
-        var margin = 20;
-        var nbInner = $('#notebook-container');
-        var nbWrapWidth = $('#notebook').width();
-        var sidebar = $(vpCommon.getVPContainer());
-        var visibleSidebar = cfg.sideBar && sidebar.is(':visible');
-        var sidebarWidth = visibleSidebar ? sidebar.outerWidth() : 0;
-        var availableSpace = nbWrapWidth - 2 * margin - sidebarWidth;
+        var containerWidth = $(vpCommon.getVPContainer()).is(":visible") ? $(vpCommon.getVPContainer()).width() + 6 : 0;
+        var jupyterWidth = $(window).width() - containerWidth;
         
-        var innerCtyle = {
-            marginRight: '',
-            width: ''
-        };
-        if (cfg.widenNotebook) {
-            innerCtyle.width = availableSpace;
-        }
-        if (visibleSidebar) {
-            var nbInnerWidth = nbInner.outerWidth();
-            if (availableSpace <= nbInnerWidth + sidebarWidth + 42) {
-                innerCtyle.marginRight = sidebarWidth + margin + 42; // shift notebook rightward to fit the sidebar in
-                if (availableSpace <= nbInnerWidth) {
-                    innerCtyle.width = availableSpace; // also slim notebook to fit sidebar
-                }
-            }
-        }
-        nbInner.css(innerCtyle);
+        $('#site').width(jupyterWidth);
+        $('#notebook-container').width(jupyterWidth - 60 > 1140 ? 1140 : jupyterWidth - 60);
+        // var margin = 20;
+        // var nbInner = $('#notebook-container');
+        // var nbWrapWidth = $('#notebook').width();
+        // var sidebar = $(vpCommon.getVPContainer());
+        // var visibleSidebar = cfg.sideBar && sidebar.is(':visible');
+        // var sidebarWidth = visibleSidebar ? sidebar.outerWidth() : 0;
+        // var availableSpace = nbWrapWidth - 2 * margin - sidebarWidth;
+        
+        // var innerCtyle = {
+        //     marginRight: '',
+        //     width: ''
+        // };
+        // if (cfg.widenNotebook) {
+        //     innerCtyle.width = availableSpace;
+        // }
+        // if (visibleSidebar) {
+        //     var nbInnerWidth = nbInner.outerWidth();
+        //     if (availableSpace <= nbInnerWidth + sidebarWidth + 42) {
+        //         innerCtyle.marginRight = sidebarWidth + margin + 42; // shift notebook rightward to fit the sidebar in
+        //         if (availableSpace <= nbInnerWidth) {
+        //             innerCtyle.width = availableSpace; // also slim notebook to fit sidebar
+        //         }
+        //     }
+        // }
+        // nbInner.css(innerCtyle);
     }
 
     /**
@@ -320,7 +325,7 @@
         var viewRect = (liveNotebook ? document.getElementById('site') : document.body).getBoundingClientRect();
         var wrap = $(vpCommon.getVPContainer()).addClass('sidebar-wrapper').resizable('option', 'handles', 'w');
         wrap.children('.ui-resizable-w').addClass('ui-icon ui-icon-grip-dotted-vertical');
-        wrap.css({ top: viewRect.top, height: '', right: 0 });
+        wrap.css({ top: liveNotebook ? viewRect.top : "110px", height: '', right: 0 });
         setNotebookWidth(cfg);
     };
 
@@ -347,7 +352,7 @@
         $(document).on("blur", vpCommon.wrapSelector("input[type='number']"), function() {
             Jupyter.notebook.keyboard_manager.enable();
         });
-        // minju: prefix & postfix용 - hotkey 제어 textarea 인 경우 포커스를 가지면 핫키 막고 잃으면 핫키 허용
+        // minju: textarea용 - hotkey 제어 textarea 인 경우 포커스를 가지면 핫키 막고 잃으면 핫키 허용
         $(document).on("focus", vpCommon.wrapSelector("textarea"), function() {
             Jupyter.notebook.keyboard_manager.disable();
         });
@@ -366,7 +371,8 @@
                     events.trigger('resize-container.vp-wrapper');
                 }
             })
-            .prependTo(liveNotebook ? '#site' : document.body);
+            // .prependTo(liveNotebook ? '#site' : document.body);
+            .prependTo(document.body);
         
 
         // enable dragging and save position on stop moving
@@ -394,7 +400,7 @@
         // });
 
         vpWrapper.resizable({
-            handles: 'all',
+            // handles: 'all',
             resize: function (event, ui) {
                 if (cfg.sideBar) {
                     // unset the height set by jquery resizable
@@ -408,11 +414,14 @@
                     cfg.vp_section_display = setVpMetaData('vp_section_display', true);
                     toggleMinimized(cfg);
                 }
+                $(this).resizable( "option", "maxWidth", $(document).width() * 0.8);
             },
             stop: saveVpPosition,
             containment: 'parent',
-            minHeight: 100,
-            minWidth: 165
+            // minHeight: 100,
+            // minWidth: 165,
+            handles: 'w',
+            resizeHeight: false
         });
 
         // On header/menu/toolbar resize, resize the vp itself
@@ -458,8 +467,8 @@
         if (!liveNotebook)
             cfg = $.extend(true, {}, defaultConfig, cfg);
         
-        // FIXME: css 재조정
-        vpCommon.loadCss(Jupyter.notebook.base_url + vpConst.BASE_PATH + vpConst.STYLE_PATH +  "container" + vpConst.PATH_SEPARATOR + "vpContainer.css");
+        // 구버전 css load
+        // vpCommon.loadCss(Jupyter.notebook.base_url + vpConst.BASE_PATH + vpConst.STYLE_PATH +  "container" + vpConst.PATH_SEPARATOR + "vpContainer.css");
         
         var vpWrapper = $(vpCommon.getVPContainer());
         if (vpWrapper.length === 0) { // vp window doesn't exist at all
@@ -491,6 +500,22 @@
             events.trigger('resize-container.vp-wrapper');
     };
 
+    /**
+     * 사용할 파이썬 코드를 함수로 구성해 초기에만 한 번 실행함
+     */
+    var read_kernel_functions = function() {
+        // FIXME: 여러 개 파일 받아올 것도 고려해야 함
+        var libName = Jupyter.notebook.base_url + "nbextensions/visualpython/src/api/functions/getPath.py";
+        $.get(libName).done(function(data) {
+            var code_init = data;
+            Jupyter.notebook.kernel.execute(code_init, { iopub: { output: function(data) {
+                console.log('visualpython - loaded library', data);
+            } } }, { silent: false });
+        }).fail(function() {
+            console.log('visualpython - failed to load getPath library');
+        });
+    }
+
     /**
      * 외부 호출 Init
      * @param {defaultConfig} cfg 설정값
@@ -501,6 +526,9 @@
         if (cfg === undefined) {
             cfg = readConfig();
         }
+
+        // vp 내부 커널 함수 실행
+        read_kernel_functions();
         
         // 추가 스타일 설정
         adjustAdditionalStyle(cfg);
